@@ -1,21 +1,12 @@
 #include <config.h>
-#include <libintl.h>
+#include <glib.h>
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkx.h>
 #include <gdk/gdkkeysyms.h>
 #include "eggcellrendererkeys.h"
 #include "eggaccelerators.h"
 
-#ifndef EGG_COMPILATION
-	#ifndef _
-		#define _(x) dgettext (GETTEXT_PACKAGE, x)
-		#define N_(x) x
-	#endif
-#else
-	#define _(x) x
-	#define N_(x) x
-#endif
-
 #define EGG_CELL_RENDERER_TEXT_PATH "egg-cell-renderer-text"
 
 #define TOOLTIP_TEXT _("New shortcut...")
@@ -31,7 +22,6 @@ static GtkCellEditable *egg_cell_renderer_keys_start_editing (GtkCellRenderer
 							      const GdkRectangle       *cell_area,
 							      GtkCellRendererState      flags);
 
-
 static void egg_cell_renderer_keys_get_property (GObject         *object,
 						 guint            param_id,
 						 GValue          *value,
@@ -48,7 +38,6 @@ static void egg_cell_renderer_keys_get_size	(GtkCellRenderer    *cell,
 						 gint               *width,
 						 gint               *height);
 
-
 enum {
   PROP_0,
 
@@ -75,7 +64,8 @@ GType egg_cell_renderer_keys_get_type(void)
 			NULL,		/* class_data */
 			sizeof (EggCellRendererKeys),
 			0,              /* n_preallocs */
-			(GInstanceInitFunc) egg_cell_renderer_keys_init
+			(GInstanceInitFunc) egg_cell_renderer_keys_init,
+			NULL
 		};
 
 	  cell_keys_type = g_type_register_static (GTK_TYPE_CELL_RENDERER_TEXT, "EggCellRendererKeys", &cell_keys_info, 0);
@@ -213,7 +203,6 @@ egg_cell_renderer_keys_class_init (EggCellRendererKeysClass *cell_keys_class)
 		G_TYPE_STRING);
 }
 
-
 GtkCellRenderer* egg_cell_renderer_keys_new(void)
 {
 	return GTK_CELL_RENDERER(g_object_new(EGG_TYPE_CELL_RENDERER_KEYS, NULL));
@@ -531,6 +520,7 @@ pointless_eventbox_subclass_get_type (void)
         sizeof (GtkEventBox),
 	0,              /* n_preallocs */
         (GInstanceInitFunc) NULL,
+        NULL
       };
 
       static const GInterfaceInfo cell_editable_info = {
@@ -632,7 +622,7 @@ egg_cell_renderer_keys_start_editing (GtkCellRenderer      *cell,
 
   keys->grab_widget = widget;
 
-  g_signal_connect (G_OBJECT (widget), "key_press_event",
+  g_signal_connect (widget, "key_press_event",
                     G_CALLBACK (grab_key_callback),
                     keys);
 
@@ -669,8 +659,9 @@ egg_cell_renderer_keys_start_editing (GtkCellRenderer      *cell,
 
   gtk_widget_show_all (keys->edit_widget);
 
-  g_signal_connect (G_OBJECT (keys->edit_widget), "unrealize",
-                    G_CALLBACK (ungrab_stuff), keys);
+  g_signal_connect (keys->edit_widget, "unrealize",
+                    G_CALLBACK (ungrab_stuff),
+                    keys);
 
   keys->edit_key = keys->accel_key;
 
